@@ -8,6 +8,7 @@ import json
 import pandas as pd
 
 
+
 class StorageEntry:
     key: str
     value: str
@@ -74,18 +75,22 @@ class ChipmunkDb():
         letters = string.ascii_lowercase
         return ''.join(random.choice(letters) for i in range(10))
 
+    def save_collection(self, collection):
+
+        res = requests.post(url=self.getHostAndPort()+'/collection/'+collection+'/save')
+        return res.json()
+
     def save_as_pandas(self, df, collection, mode="append", domain=None, session_id=None, end=False):
 
-        # if df is larger than 500MB, we iterate over it
-        if df.memory_usage().sum() > 500000000:
+        if session_id is None:
             # lets iterate over the dataframe and send chunks with a session_id
             session_id = self.generate_random_id()
 
             while True:
-                chunk = df.head(60000)
+                chunk = df.head(40000)
                 if chunk.empty:
                     break
-                df = df.tail(-60000)
+                df = df.tail(-40000)
                 self.save_as_pandas(chunk, collection, mode=mode, domain=domain, session_id=session_id, end=df.shape[0] == 0)
 
         else:
